==> nextcloud-31.0.2-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_reminders/l10n/en_GB.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "File reminders",
    "Reminder for {name}" : "Reminder for {name}",
    "View file" : "View file",
    "View folder" : "View folder",
    "Set file reminders" : "Set file reminders",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly.",
    "Set reminder for \"{fileName}\"" : "Set reminder for \"{fileName}\"",
    "Set reminder at custom date & time" : "Set reminder at custom date & time",
    "Clear reminder" : "Clear reminder",
    "Please choose a valid date & time" : "Please choose a valid date & time",
    "Reminder set for \"{fileName}\"" : "Reminder set for \"{fileName}\"",
    "Failed to set reminder" : "Failed to set reminder",
    "Reminder cleared for \"{fileName}\"" : "Reminder cleared for \"{fileName}\"",
    "Failed to clear reminder" : "Failed to clear reminder",
    "We will remind you of this file" : "We will remind you of this file",
    "Cancel" : "Cancel",
    "Set reminder" : "Set reminder",
    "Reminder set" : "Reminder set",
    "Set custom reminder" : "Set custom reminder",
    "Later today" : "Later today",
    "Set reminder for later today" : "Set reminder for later today",
    "Tomorrow" : "Tomorrow",
    "Set reminder for tomorrow" : "Set reminder for tomorrow",
    "This weekend" : "This weekend",
    "Set reminder for this weekend" : "Set reminder for this weekend",
    "Next week" : "Next week",
    "Set reminder for next week" : "Set reminder for next week"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_reminders/l10n/en_GB.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "File reminders",
    "Reminder for {name}" : "Reminder for {name}",
    "View file" : "View file",
    "View folder" : "View folder",
    "Files reminder" : "Files reminder",
    "This files_reminder can work properly." : "This files_reminder can work properly.",
    "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder.",
    "Set file reminders" : "Set file reminders",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly.",
    "Set reminder for \"{fileName}\"" : "Set reminder for \"{fileName}\"",
    "Set reminder at custom date & time" : "Set reminder at custom date & time",
    "Clear reminder" : "Clear reminder",
    "Please choose a valid date & time" : "Please choose a valid date & time",
    "Reminder set for \"{fileName}\"" : "Reminder set for \"{fileName}\"",
    "Failed to set reminder" : "Failed to set reminder",
    "Reminder cleared for \"{fileName}\"" : "Reminder cleared for \"{fileName}\"",
    "Failed to clear reminder" : "Failed to clear reminder",
    "We will remind you of this file" : "We will remind you of this file",
    "Cancel" : "Cancel",
    "Set reminder" : "Set reminder",
    "Reminder set" : "Reminder set",
    "Set custom reminder" : "Set custom reminder",
    "Later today" : "Later today",
    "Set reminder for later today" : "Set reminder for later today",
    "Tomorrow" : "Tomorrow",
    "Set reminder for tomorrow" : "Set reminder for tomorrow",
    "This weekend" : "This weekend",
    "Set reminder for this weekend" : "Set reminder for this weekend",
    "Next week" : "Next week",
    "Set reminder for next week" : "Set reminder for next week"
},
"nplurals=2; plural=(n != 1);");
